package com.srs.android.widgets;

import java.util.Vector;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;
import android.widget.ImageView;

import com.srs.quiltmaker.android.ui.bean.Layer;
import com.srs.quiltmaker.android.ui.bean.QuiltBackgroundItem;

public class LayeredImageView extends ImageView {

	int origX=25,origY=25;
	boolean movingFlg=false;
	float origTouchX,origTouchY;
	Vector layers = new Vector();
	
	public LayeredImageView(Context context) {
		super(context);
	}
	
	public void addLayer(Object layeredItem) {
		layers.add(layeredItem);
	}
	
	/**
	 * Consume all remaining space.
	 * 
	 * Notes:  For some reason can't get this to auto happen with the default onMeasure, so
	 * had to roll my own.  Not a problem, however very curious none the less.
	 * 
	 */
	protected void  onMeasure  (int widthMeasureSpec, int heightMeasureSpec) {
		int width = View.MeasureSpec.getSize(widthMeasureSpec);
		int height= View.MeasureSpec.getSize(heightMeasureSpec);
		int mode = View.MeasureSpec.getMode(widthMeasureSpec);
	
		Log.d("LayeredImageView","onmeasure provided dimentions are " + width + "," + height);
		//Log.d("LayeredImageView","onmeasure mode is " + mode);

		setMeasuredDimension(width, height);
	}
	
	protected void onDraw(Canvas can) {
		Paint pt = new Paint();
		pt.setColor(0xFFd6d6d6);
		can.drawRect((float) 0.0,(float) 0.0,(float) getWidth(),(float) getHeight(),pt);
		
		for(int i=0;i < layers.size();i++) {
			Layer current = (Layer) layers.get(i);
			if(current.isVisible()) {
				QuiltBackgroundItem item = (QuiltBackgroundItem) current.getLayerData();
				if(item != null) {
					if(i + 1 == layers.size() && current.isPlaceable()) {
						can.drawBitmap(item.getBackground(),origX,origY,null);
						
						//
						// Implementation note:  This might/should be in the ontouch event.  For simplicity we
						// put this here since we are already de-referencing all the layers here anyway
						//
						item.setPositionX(origX);
						item.setPositionY(origY);
					}
					else {
						can.drawBitmap(item.getBackground(),item.getPositionX(),item.getPositionY(),null);
					}
				}
			}
		}
		
	}
	
	public boolean onTouchEvent(MotionEvent event) {
		
		if(event.getAction() == MotionEvent.ACTION_DOWN) {
					movingFlg=true;
					origTouchX = event.getX();
					origTouchY = event.getY();
				}
		if(movingFlg && event.getAction() ==MotionEvent.ACTION_MOVE) {
			float diffX =  event.getX() - origTouchX;
			float diffY =  event.getY() - origTouchY;
			origTouchX = event.getX();
			origTouchY = event.getY();
			origX += diffX;
			origY += diffY;
			invalidate();
		}
		if(event.getAction() ==MotionEvent.ACTION_UP && movingFlg) {
			movingFlg=false;
		}

		return true;
	}

}
