package com.srs.android.widgets;

import android.graphics.Bitmap;

/**
 * This POJO bean provides an encapsulation of a graphical navigation component that supports a selected image,
 * a non selected image, and a moused over image.
 * 
 * @author k001694
 *
 */
public class MouseoverNavigationElement {

	public static int LOC_FIXED=100;
	public static int LOC_FLOAT_LEFT=101;
	public static int LOC_FLOAT_RIGHT=102;
	
	private String name;
	
	/**
	 *  this is utilized to determine if the user set the fixed location, or if we are computing the location
	 *  dynamically.
	 */
	private int locationMode= MouseoverNavigationElement.LOC_FLOAT_LEFT;
	private int origanX, origanY;
	private boolean selectedFlg = false;
	private boolean mousedOverFlg = false;
	private boolean enabled = true;
	private Bitmap selectedImage=null;
	private Bitmap nonselectedImage = null;
	private String selectedImageFilename=null;
	private int selectedImageResource;
	private String nonselectedImageFilename=null;
	private int nonselectedImageResource;
	private String mouseOverImageFilename=null;
	private int mouseOverImageResource;
	private Object actionListener;
	
	public MouseoverNavigationElement(String name) {
		this.name = name;
	}
	
	public MouseoverNavigationElement(String name, String selectedImageFilename,String nonselectedImageFilename,
			Object actionListener) {
		this.name= name;
		this.selectedImageFilename = selectedImageFilename;
		this.nonselectedImageFilename = nonselectedImageFilename;
		this.actionListener = actionListener;
	}
	
	public MouseoverNavigationElement(String name, int selectedImageResource,int nonselectedImageResource,
			Object actionListener) {
		this.name= name;
		this.selectedImageResource = selectedImageResource;
		this.nonselectedImageResource = nonselectedImageResource;
		this.actionListener = actionListener;
	}

	
	public int getLocationMode() {
		return locationMode;
	}

	public void setLocationMode(int locationMode) {
		this.locationMode = locationMode;
	}

	public int getOriganX() {
		return origanX;
	}

	public void setOriganX(int origanX) {
		this.origanX = origanX;
	}

	public int getOriganY() {
		return origanY;
	}

	public void setOriganY(int origanY) {
		this.origanY = origanY;
	}

	public boolean isSelectedFlg() {
		return selectedFlg;
	}

	public void setSelectedFlg(boolean selectedFlg) {
		this.selectedFlg = selectedFlg;
	}

	public boolean isMousedOverFlg() {
		return mousedOverFlg;
	}

	public void setMousedOverFlg(boolean mousedOverFlg) {
		this.mousedOverFlg = mousedOverFlg;
	}

	public boolean isEnabled() {
		return enabled;
	}

	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
	}

	public Bitmap getSelectedImage() {
		return selectedImage;
	}

	public void setSelectedImage(Bitmap selectedImage) {
		this.selectedImage = selectedImage;
	}

	public Bitmap getNonselectedImage() {
		return nonselectedImage;
	}

	public void setNonselectedImage(Bitmap nonselectedImage) {
		this.nonselectedImage = nonselectedImage;
	}

	public String getSelectedImageFilename() {
		return selectedImageFilename;
	}

	public void setSelectedImageFilename(String selectedImageFilename) {
		this.selectedImageFilename = selectedImageFilename;
	}

	public String getNonselectedImageFilename() {
		return nonselectedImageFilename;
	}

	public void setNonselectedImageFilename(String nonselectedImageFilename) {
		this.nonselectedImageFilename = nonselectedImageFilename;
	}

	public String getMouseOverImageFilename() {
		return mouseOverImageFilename;
	}

	public void setMouseOverImageFilename(String mouseOverImageFilename) {
		this.mouseOverImageFilename = mouseOverImageFilename;
	}

	public Object getActionListener() {
		return actionListener;
	}

	public void setActionListener(Object actionListener) {
		this.actionListener = actionListener;
	}

	public String getName() {
		return name;
	}

	public int getSelectedImageResource() {
		return selectedImageResource;
	}

	public void setSelectedImageResource(int selectedImageResource) {
		this.selectedImageResource = selectedImageResource;
	}

	public int getNonselectedImageResource() {
		return nonselectedImageResource;
	}

	public void setNonselectedImageResource(int nonselectedImageResource) {
		this.nonselectedImageResource = nonselectedImageResource;
	}

	public int getMouseOverImageResource() {
		return mouseOverImageResource;
	}

	public void setMouseOverImageResource(int mouseOverImageResource) {
		this.mouseOverImageResource = mouseOverImageResource;
	}
	
}
