package com.srs.android.widgets;

import java.util.LinkedList;
import java.util.List;


import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;
import android.widget.ImageView;

/**
 * The NavigationView class implements a graphical navigation UI.   This implementation is
 * identical to the com.srs.swing.ui.NavPannel class which is provided for such navigation in swing, with
 * the appropriate adjustments made for the Android environment APIs.
 * 
 * @author Aaron Myers
 *
 */
public class NavigationView extends ImageView {
	
	private List navigationElements = (List) new LinkedList();
	int backgroundColor;
	boolean hasBackgroundColor;
	
	public NavigationView(String backgroundImageFilename,Context context) {
		super(context);
	}
	
	public NavigationView(int backgroundResourceId,Context context) {
		super(context);
	}
	
	public NavigationView(Context context) {
		super(context);
	}
	
	public void setBackgroundColor(int color) {
		backgroundColor = color;
		hasBackgroundColor=true;
		super.setBackgroundColor(color);
	}
	
	/**
	 * Adds a mouse over navigation menu to this view.
	 * 
	 * The image file names listed for element.getSelectedImageFilename and element.getNonselectedImageFilename are
	 * loaded via the classloader.  The image elements are added into the navigation element.
	 * 
	 * If the images are already loaded in the element, the loaded images are utilized and no image loading is
	 * performed.
	 * 
	 * @param element
	 */
	public void add(MouseoverNavigationElement element) {
		navigationElements.add(element);
		
		if(element.getSelectedImage() == null) {
			if(element.getSelectedImageFilename() != null) {
				// TODO: implement
			} else {
				Bitmap viewImage = BitmapFactory.decodeResource(getResources(),element.getSelectedImageResource());
				element.setSelectedImage(viewImage);
			}
		}
		
		if(element.getNonselectedImage() == null) {
			if(element.getNonselectedImageFilename() != null) {
				
			} else {
				Bitmap viewImage = BitmapFactory.decodeResource(getResources(),element.getNonselectedImageResource());
				element.setNonselectedImage(viewImage);
			}
		}
	}

	protected void  onMeasure  (int widthMeasureSpec, int heightMeasureSpec) {
		int width = View.MeasureSpec.getSize(widthMeasureSpec);
		int height = View.MeasureSpec.getSize(heightMeasureSpec);
		int mode = View.MeasureSpec.getMode(widthMeasureSpec);
	
		Log.d("NavPanel","onmeasure provided dimentions are " + width + "," + height);
		Log.d("NavPanel","onmeasure mode is " + mode);

		int i=0;
		int computedHeight=0;
		while(i < navigationElements.size()) {
			MouseoverNavigationElement e = (MouseoverNavigationElement) navigationElements.get(i);
			if(e.getSelectedImage() != null) {
				if(e.getSelectedImage().getHeight() > computedHeight)
					computedHeight = e.getSelectedImage().getHeight();
			}
			
			i++;
		}
		
		i=0;
		int currFloatLeftX=0;
		int currFloatRightX=width;
		while(i < navigationElements.size()) {
			MouseoverNavigationElement e = (MouseoverNavigationElement) navigationElements.get(i);
			if(e.getLocationMode() == MouseoverNavigationElement.LOC_FLOAT_LEFT) {
				e.setOriganX(currFloatLeftX);
				e.setOriganY(0);
				currFloatLeftX += e.getSelectedImage().getWidth();
			}

			if(e.getLocationMode() == MouseoverNavigationElement.LOC_FLOAT_RIGHT) {
				currFloatRightX -= e.getSelectedImage().getWidth();
				e.setOriganX(currFloatRightX);
				e.setOriganY(0);
			}
			
			i++;
		}
		
		// NOTES:  We have not taken into account the height the parent provided.
		//         Guess we should. Do this later.
		setMeasuredDimension(width, computedHeight);
	}
	
	protected void onDraw(Canvas can) {

		//Log.d("TestView","dimentions are " + getWidth() + " " + getHeight());
		
		if(hasBackgroundColor) {
			Paint pt = new Paint();
			pt.setColor(backgroundColor);
			can.drawRect((float) 0.0,(float) 0.0,(float) getWidth(),(float) getHeight(),pt);
		}
		
		int i=0;
		while(i < navigationElements.size()) {
			MouseoverNavigationElement e = (MouseoverNavigationElement) navigationElements.get(i);
			if(e.isSelectedFlg())
				can.drawBitmap(e.getSelectedImage(),e.getOriganX(),e.getOriganY(),null);
			else
				can.drawBitmap(e.getNonselectedImage(),e.getOriganX(),e.getOriganY(),null);
			
			i++;
			
		}
	}
	
	public boolean onTouchEvent(MotionEvent event) {
		
		if(event.getAction() == MotionEvent.ACTION_DOWN ||  event.getAction() ==MotionEvent.ACTION_MOVE) {
			
			float currX = event.getX();
			float currY = event.getY();
			
			int i=0;
			while(i < navigationElements.size()) {
				MouseoverNavigationElement e = (MouseoverNavigationElement) navigationElements.get(i);
				
				float maxDimentionX = e.getOriganX() + e.getNonselectedImage().getWidth();
				float maxDimentionY = e.getOriganY() + e.getNonselectedImage().getHeight();

				if((currX >= e.getOriganX() && currY >= e.getOriganY()) &&
						(currX <= maxDimentionX && currY <= maxDimentionY)) {
					e.setSelectedFlg(true);
				} else {
					e.setSelectedFlg(false);
				}

				i++;
				
			}
			
			invalidate();
		}

		if(event.getAction() == MotionEvent.ACTION_UP) {
			
			float currX = event.getX();
			float currY = event.getY();
			MouseoverNavigationElement activeElement=null;
			
			int i=0;
			while(i < navigationElements.size()) {
				MouseoverNavigationElement e = (MouseoverNavigationElement) navigationElements.get(i);
				
				float maxDimentionX = e.getOriganX() + e.getNonselectedImage().getWidth();
				float maxDimentionY = e.getOriganY() + e.getNonselectedImage().getHeight();

				if((currX >= e.getOriganX() && currY >= e.getOriganY()) &&
						(currX <= maxDimentionX && currY <= maxDimentionY)) {
					e.setSelectedFlg(false);
					activeElement = e;
				} else {
					e.setSelectedFlg(false);
				}
				i++;
			}
			
			// re-draw screen (in case click action is long running
			invalidate();
			// preform click delegation
			OnClickListener oc = (OnClickListener) activeElement.getActionListener();
			if(oc != null)
				oc.onClick(this);
			
		}
		return true;
	}
}
