package com.srs.android.widgets.layout;

import android.content.Context;
import android.graphics.Canvas;
import android.util.Log;
import android.view.View;
import android.widget.LinearLayout;

/**
 * 
 * This layout provides support for Views that have both a header, and footer, in additon to a central "body".
 * For such a view the height of the header and footer are calculated first, and then the remainder of the space
 * is provided to the body of the page for utilization.
 * 
 * @author k001694
 *
 */
public class HeaderFooterLayout extends LinearLayout {

	private View header;
	private View footer;
	private View body;
	
	public HeaderFooterLayout(Context context) {
		super(context);
		// TODO Auto-generated constructor stub
	}

	public void addHeaderView(View child1) {
		header = child1;
		super.addView(child1);
	}
	
	public void addBodyView(View child2) {
		body = child2;
		super.addView(child2);
	}
	
	public void addFooterView(View child3) {
		footer = child3;
		super.addView(child3);
	}
	
	protected void  onMeasure  (int widthMeasureSpec, int heightMeasureSpec) {
		int width = View.MeasureSpec.getSize(widthMeasureSpec);
		int origheight;
		int height= origheight = View.MeasureSpec.getSize(heightMeasureSpec);
		int mode = View.MeasureSpec.getMode(widthMeasureSpec);
	
		Log.d("HeaderFooterLayout","onmeasure dimentions are " + width + "," + height);
		Log.d("HeaderFooterLayout","onmeasure mode is " + mode);

		//
		// compute upper
		//
		if(header != null) {
			int childWidthMeasureSpec = View.MeasureSpec.makeMeasureSpec(width, View.MeasureSpec.AT_MOST);
			int childHightMeasureSpec = View.MeasureSpec.makeMeasureSpec(height,View.MeasureSpec.AT_MOST);
			header.measure(childWidthMeasureSpec,childHightMeasureSpec);
			
			height -= header.getMeasuredHeight();
			Log.d("HeaderFooterLayout","upper dimentions are " + header.getMeasuredWidth() + "," + header.getMeasuredHeight());
		}
		
		//
		// compute lower
		//
		if(footer != null) {
			int childWidthMeasureSpec = View.MeasureSpec.makeMeasureSpec(width, View.MeasureSpec.AT_MOST);
			int childHightMeasureSpec = View.MeasureSpec.makeMeasureSpec(height,View.MeasureSpec.AT_MOST);
			footer.measure(childWidthMeasureSpec,childHightMeasureSpec);
			height -= footer.getMeasuredHeight();
			Log.d("HeaderFooterLayout","footer dimentions are " + footer.getMeasuredWidth() + "," + footer.getMeasuredHeight());
		}
		
		
		//
		// compute body
		//
		if(body != null) {
			int childWidthMeasureSpec = View.MeasureSpec.makeMeasureSpec(width, View.MeasureSpec.AT_MOST);
			int childHightMeasureSpec = View.MeasureSpec.makeMeasureSpec(height,View.MeasureSpec.AT_MOST);
			body.measure(childWidthMeasureSpec,childHightMeasureSpec);
			Log.d("HeaderFooterLayout","body dimentions are " + body.getMeasuredWidth() + "," + body.getMeasuredHeight());
		}
		
		
		// Consume all the space we were provided, setting our own measured dimentions
		setMeasuredDimension(width,origheight);
		
	}
	  
	protected void onDraw(Canvas can) {
		
		Log.d("HeaderFooterLayout","onDraw");
		
		if(header !=  null) {
			header.draw(can);
		}
		
		if(body != null) {
			body.draw(can);
		}
		
		if(footer != null) {
			footer.draw(can);
		}
	}
}
