package com.srs.quiltmaker.android;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.StringTokenizer;
import java.util.Vector;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.View.OnClickListener;
import android.widget.AdapterView.OnItemClickListener;

import com.srs.android.widgets.LayeredImageView;
import com.srs.quiltmaker.android.ui.AccentOneSelectionNextClickListener;
import com.srs.quiltmaker.android.ui.BackgroundClickListener;
import com.srs.quiltmaker.android.ui.bean.Layer;
import com.srs.quiltmaker.android.ui.bean.QuiltBackgroundItem;
import com.srs.quiltmaker.android.util.AppConstants;
import com.srs.quiltmaker.android.util.ImageDownloader;
import com.srs.quiltmaker.android.util.StateLoadingUtil;

public class AccentOneSelectionActivity extends BaseSelectionActivity {
	
    Layer background=new Layer();
    Layer subject=new Layer();
    Layer accentOne = new Layer();
    Vector accents=null;
    LayeredImageView layerView;
    
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
	}

	/**
	 * Implementation of the abstract parent method for initing this class.
	 */
	public void onCreateInit() {
		StateLoadingUtil.loadSelectedBackground(this,background);
		StateLoadingUtil.loadSubjectBackground(this,subject);
		prepAppDataStorage();
		accents = getGalleryElements();

	}

	/**
	 * Implmentation of the abstract parent method for this object.
	 */
	public int getBackgroundResource() {
		return R.raw.stepthreeitemoneheader;
	}

	public void setUpDisplayLayers(LayeredImageView layerView) {
		background.setVisible(true);
		subject.setVisible(true);
		accentOne.setVisible(false);
		accentOne.setPlaceable(true);
		layerView.addLayer(background);
		layerView.addLayer(subject);
		layerView.addLayer(accentOne);

		// Save off for later
		this.layerView = layerView;
	}

	public Vector getGalleryItems() {
		return accents;
	}

	public OnItemClickListener getGalleryItemClickListener() {
		BackgroundClickListener cl = new BackgroundClickListener(accents,
				layerView, accentOne, this);
		return cl;
	}

	public OnClickListener getResetMenuClickListener() {
		ResetClickListener resetClick = new ResetClickListener(this,subject);
		return resetClick;
	}

	public OnClickListener getNextMenuClickListener() {
		AccentOneSelectionNextClickListener nextClick = new AccentOneSelectionNextClickListener(
				this, accentOne);
		return nextClick;
	}
	
	private void prepAppDataStorage() {
    	QuiltBackgroundItem bkground = (QuiltBackgroundItem) background.getLayerData();
    	if(bkground== null)
    		return;
    	
    	File bgDataDir = getDir(AppConstants.APP_BACKGROUND_DATA_DIR,Context.MODE_PRIVATE);
    	String resourcesPath = bgDataDir.getAbsolutePath() + "/" + bkground.getName() + "/" + AppConstants.ACCENT_CACHE_DIR;
    	
    	File subBaseDirFile = new File(resourcesPath);
    	subBaseDirFile.mkdirs();
	}

	   private Vector getGalleryElements() {
	    	
	    	Vector subjects = new Vector();
	    	QuiltBackgroundItem bkground = (QuiltBackgroundItem) background.getLayerData();
	    	
	    	File bgDataDir = getDir(AppConstants.APP_BACKGROUND_DATA_DIR,Context.MODE_PRIVATE);
	    	String resourceDefinitionPath = bgDataDir.getAbsolutePath() + "/" + bkground.getName() + "/" + AppConstants.ACCENT_CACHE_DIR + "/accent.rc";
	    	String imageRootPath = bgDataDir.getAbsolutePath() + "/" + bkground.getName() + "/" + AppConstants.ACCENT_CACHE_DIR;
	    	
	    	tempDownload(AppConstants.HTTP_ROOT_DIR + "/" + bkground.getName() + "/" + AppConstants.ACCENT_CACHE_DIR + "/accent.rc",resourceDefinitionPath);
	    	
	    	Log.v("subject activity","path is " + resourceDefinitionPath);
	    	
	    	try {
				BufferedReader rd = new BufferedReader(new FileReader(resourceDefinitionPath));
				String line = null;
				line=rd.readLine();
				while(line != null) {
					StringTokenizer st = new StringTokenizer(line,",");
					String name = st.nextToken();
					String fileThumb = st.nextToken();
					String file = st.nextToken();
					
					QuiltBackgroundItem sub = new QuiltBackgroundItem(name);
					sub.setBackgroundFilename(file);
					sub.setBackgroundThumFilename(fileThumb);
					sub.setRootDirectory(imageRootPath);
					
			    	tempDownload(AppConstants.HTTP_ROOT_DIR + "/" + bkground.getName() + "/" + AppConstants.ACCENT_CACHE_DIR + "/" + file,
			    			imageRootPath + "/" + file);
			    	tempDownload(AppConstants.HTTP_ROOT_DIR + "/" + bkground.getName() + "/" + AppConstants.ACCENT_CACHE_DIR + "/" + fileThumb,
			    			imageRootPath + "/" + fileThumb);

					Log.i("SubjectActivity","BK is " + sub.getBackgroundFilename());
					Log.i("SubjectActivity","TH is " + sub.getBackgroundThumFilename());
					loadItemImages(sub);
					subjects.add(sub);
					
					line = rd.readLine();
				}
				
				rd.close();
				
			} catch (FileNotFoundException e) {
				Log.e("SubjectActivity","getSubjects unable to find subject rc file.",e);
				return subjects;
			} catch (IOException e) {
				Log.e("SubjectActivity","getSubjects IO error reading subject rc file.",e);
				return subjects;
			}
	    	
	    	return subjects;
	    }
	   
    private void tempDownload(String URIPath,String file) {
    	ImageDownloader downloader = new ImageDownloader();
    	downloader.DownloadFromUrl(URIPath,file);
    }

}
