package com.srs.quiltmaker.android;

import java.util.Vector;

import android.app.Activity;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.util.Log;
import android.view.View.OnClickListener;
import android.widget.Gallery;
import android.widget.LinearLayout;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.RadioGroup.LayoutParams;

import com.srs.android.widgets.CenteredImageView;
import com.srs.android.widgets.LayeredImageView;
import com.srs.android.widgets.MouseoverNavigationElement;
import com.srs.android.widgets.NavigationView;
import com.srs.android.widgets.layout.HeaderFooterLayout;
import com.srs.quiltmaker.android.ui.BackgroundGaleryAdaptor;
import com.srs.quiltmaker.android.ui.bean.QuiltBackgroundItem;

public abstract class BaseSelectionActivity extends Activity {

	
	abstract public void onCreateInit();
	abstract public int getBackgroundResource();
	abstract public void setUpDisplayLayers(LayeredImageView theView);
	abstract public Vector getGalleryItems();
	abstract public OnItemClickListener getGalleryItemClickListener();
	abstract public OnClickListener getResetMenuClickListener();
	abstract public OnClickListener getNextMenuClickListener();
	//abstract public void prepAppDataStorage();

	
    public void onCreate(Bundle savedInstanceState) {
    	super.onCreate(savedInstanceState);
    	
        
        //
        //  Init layers from pervious steps
        //
    	onCreateInit();
        
        HeaderFooterLayout mainLayout = new HeaderFooterLayout(this);
        mainLayout.setOrientation(LinearLayout.VERTICAL);
        
        
        //
        //   ****  HEADER ****
        //
        CenteredImageView header = new CenteredImageView(this);
        header.setImageResource(getBackgroundResource());
        header.setConsumeParentWidth(true);
        header.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT,LayoutParams.WRAP_CONTENT));
        mainLayout.addHeaderView(header);
        
   
        //
        //   ****  BODY ****
        //
        LayeredImageView theView = new LayeredImageView(this);
        theView.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT,LayoutParams.FILL_PARENT));
        theView.setMinimumHeight(100);
        theView.setMaxHeight(400);
        mainLayout.addBodyView(theView);

        // set up layers
        setUpDisplayLayers(theView);
       
        
        //
        //   ****  FOOTER ****
        //
        LinearLayout footerLayout = new LinearLayout(this);
        footerLayout.setOrientation(LinearLayout.VERTICAL);
        
        
        Gallery backgroundGallery = new Gallery(this);
        backgroundGallery.setMinimumHeight(100);
        backgroundGallery.setMinimumWidth(100);
        backgroundGallery.setSpacing(4);
        backgroundGallery.setLayoutParams(new Gallery.LayoutParams(LayoutParams.FILL_PARENT,LayoutParams.WRAP_CONTENT));
        BackgroundGaleryAdaptor gadaptor = new BackgroundGaleryAdaptor(this);
        gadaptor.setItemVector(getGalleryItems());
        backgroundGallery.setAdapter(gadaptor);
        backgroundGallery.setOnItemClickListener(getGalleryItemClickListener());
        
        footerLayout.addView(backgroundGallery,new Gallery.LayoutParams(LayoutParams.FILL_PARENT,LayoutParams.WRAP_CONTENT));

        
        NavigationView footerMenu = new NavigationView(this);
        footerMenu.setBackgroundColor(0xFFe3e2a6);
        
        MouseoverNavigationElement nextButton = new MouseoverNavigationElement("Next",R.raw.nextbtnselected,
        		R.raw.nextbtnsonselected,getNextMenuClickListener());
        nextButton.setLocationMode(MouseoverNavigationElement.LOC_FLOAT_RIGHT);
        footerMenu.add(nextButton);
        
        MouseoverNavigationElement resetButton = new MouseoverNavigationElement("Reset",R.raw.resetbtnselected,
        		R.raw.resetbtnnonselected,getResetMenuClickListener());
        resetButton.setLocationMode(MouseoverNavigationElement.LOC_FLOAT_LEFT);
        footerMenu.add(resetButton);
        footerLayout.addView(footerMenu);

        mainLayout.addFooterView(footerLayout);
        setContentView(mainLayout);
    }
    

    protected void loadItemImages(QuiltBackgroundItem item) {
    	Log.i("BaseSelectActivity","loadItemImages: " + item.getRootDirectory() + "/" + item.getBackgroundThumFilename());
    	Bitmap img = BitmapFactory.decodeFile(item.getRootDirectory() + "/" + item.getBackgroundThumFilename());
    	item.setBackgroundThum(img);
    	
    	img=null;
    	img = BitmapFactory.decodeFile(item.getRootDirectory() + "/" + item.getBackgroundFilename());
    	item.setBackground(img);
    }
}
