package com.srs.quiltmaker.android.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;


import android.content.Context;
import android.util.Log;

public class StateStorageUtil {

	
	/**
	 * Utility method encapsulating accessing state storage of the app.
	 * The app should access the data via this function only as implementation may/can change.
	 * 
	 * @param ctxt
	 * @return
	 */
	public static Properties getStateData(Context ctxt) {
		
			Log.v("QuiltMaker","StateStorageUtil: Retrieving state");
			
	        try {
				FileInputStream stream = ctxt.openFileInput(AppConstants.STATE_CONFIG_FILE_NAME);
				Properties prop = new Properties();
				try {
					prop.load(stream);
				} catch (IOException e) {
					Log.e("QuiltMaker","StateStorageUtil: IOError loading propertys",e);
				} finally {
					if(stream != null)
						try {
							stream.close();
						} catch (IOException e) {	}
				}
				return prop;
				
			} catch (FileNotFoundException e) {
				Log.e("QuiltMaker","StateStorageUtil: App props not found.");
				return null;
			}
	        
		}
	
	/**
	 * Utility method encapsulating accessing state storage of the app.
	 * The app should access the data via this function only as implementation may/can change.
	 * 
	 * @param ctxt
	 * @return
	 */
	public static boolean saveStateData(Context ctxt,Properties appProps) {
		
		FileOutputStream str=null;
		try {
			str = ctxt.openFileOutput(AppConstants.STATE_CONFIG_FILE_NAME,Context.MODE_PRIVATE);
			appProps.store(str, "incrementalSave");
			Log.v("QuiltMaker","StateStorageUtil: State stored");
			return true;
		} catch (FileNotFoundException e) {
			Log.e("QuiltMaker","StateStorageUtil: Error storing app state: FileNotFound opening output.",e);
		} catch (IOException e) {
			Log.e("QuiltMaker","StateStorageUtil: IO Error writing out props",e);
		} finally {
			if(str != null) {
				try {
					str.close();
				} catch (IOException e) { }
			}
		}
		
		return false;
	}

	/**
	 * Utility method provided to initialize app state storage.
	 * 
	 * @return
	 */
	public static Properties initStateStorage(Context ctxt) {
        
        try {
			FileInputStream stream = ctxt.openFileInput(AppConstants.STATE_CONFIG_FILE_NAME);
			Properties prop = new Properties();
			try {
				prop.load(stream);
			} catch (IOException e) {
				Log.e("BeginningActivity","IOError loading propertys",e);
			} finally {
				if(stream != null)
					try {
						stream.close();
					} catch (IOException e) {	}
			}
			return prop;
			
		} catch (FileNotFoundException e) {
			Log.i("BeginningActivity","App props not found, creating new.");
			return createNewProperties(ctxt);
		}
        
	}
	
	public static Properties createNewProperties(Context ctxt) {
		Properties newprop = new Properties();
		newprop.setProperty("currentStep","backgroundSelect");
		
		FileOutputStream str=null;
		try {
			str = ctxt.openFileOutput(AppConstants.STATE_CONFIG_FILE_NAME,Context.MODE_PRIVATE);
			newprop.store(str, "initialProps");
			Log.i("BeginningActivity","New application props created.");
		} catch (FileNotFoundException e) {
			Log.e("BeginningActivity","FileNotFound opening output to create prop.",e);
		} catch (IOException e) {
			Log.e("BeginningActivity","IO Error writing out props",e);
		} finally {
			if(str != null) {
				try {
					str.close();
				} catch (IOException e) { }
			}
		}
		return newprop;
	}
	
}
